# curvipy :triangular_ruler:	

[![Downloads](https://pepy.tech/badge/curvipy)](https://pepy.tech/project/curvipy)
![licence](https://img.shields.io/github/license/dylannalex/curvipy?color=blue)

curvipy is a Python package which aims to provide simple tools to teach the fundamentals of linear 
algebra (vectors operations, matrices and linear transformations) and the basics of functions and 
parametric curves.

<p align="center">
  <img width="400" height="400" src="../media/demo.gif?raw=true">
</p>

_**NOTE:**_ curvipy is not meant to be a precise graphing calculator, but a package for making 
animations in a few lines of code.

## :pencil2: Installation

Install curvipy package with pip:
```
$ pip install curvipy
```
or clone the repository:
```
$ git clone https://github.com/dylannalex/curvipy.git
```

## :pencil2: Usage

One of the main goals of curvpy is to be simple to use. You can check out the curvipy use guide [HERE](/docs/introduction.md).
